/*******************************************************************************
Copyright © 2023 Sebastian Roith

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*******************************************************************************/

(function(window) {

function createCheckerZusatzgeschwindigkeit(deltaX, deltaY) {
    return function() {
        if (!this.pfeile.length)
            return 'Zeichne zuerst die Zusatzgeschwindigkeit ein…';
        const lastPfeil = this.pfeile[this.pfeile.length - 1];
        return (lastPfeil.deltaX == deltaX && lastPfeil.deltaY == deltaY);
    }
}

const LEVELS = [
    {
        "task": "<p>Eine Kugel rollt nach rechts und wird abgelenkt. Unten ist die Kugel vor (links) und nach (rechts) der Ablenkung gezeichnet, die Pfeile stellen je ihre Geschwindigkeit dar.</p><p>Zeichne die Zusatzgeschwindigkeit ein. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Zusatzgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario1.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(-5, -10)
    },
    {
        "task": "<p>Eine Kugel rollt nach rechts und wird abgelenkt. Unten ist die Kugel vor (links) und nach (rechts) der Ablenkung gezeichnet, die Pfeile stellen je ihre Geschwindigkeit dar.</p><p>Zeichne die Zusatzgeschwindigkeit ein. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Zusatzgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario2.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(15, 10)
    },
    {
        "task": "<p>Eine Kugel rollt nach rechts und wird abgelenkt. Unten ist die Kugel vor (links) und nach (rechts) der Ablenkung gezeichnet, die Pfeile stellen je ihre Geschwindigkeit dar.</p><p>Zeichne die Zusatzgeschwindigkeit ein. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Zusatzgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario3.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(-25, 20)
    },
    {
        "task": "<p>Eine Kugel rollt nach rechts. Unten ist die Kugel vor (links) und nach (rechts) der Ablenkung gezeichnet, die Pfeile stellen je ihre Geschwindigkeit dar.</p><p>Zeichne die Zusatzgeschwindigkeit ein. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Zusatzgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario4.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(20, 0)
    },
    {
        "task": "<p>Eine Kugel rollt nach rechts. Unten ist die Kugel vor (links) und nach (rechts) der Ablenkung gezeichnet, die Pfeile stellen je ihre Geschwindigkeit dar.</p><p>Zeichne die Zusatzgeschwindigkeit ein. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Zusatzgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario5.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(-15, 0)
    },
    {
        "task": "<p>Eine Kugel rollt nach rechts. Unten ist die Kugel vor (links) und nach (rechts) der Ablenkung gezeichnet, die Pfeile stellen je ihre Geschwindigkeit dar.</p><p>Zeichne die Zusatzgeschwindigkeit ein. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Zusatzgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario6.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(-35, 0)
    },
    {
        "task": "<p>Eine Kugel rollt nach rechts und wird vollständig abgebremst. Unten ist die Kugel vor (links) und nach (rechts) der Ablenkung gezeichnet, die Pfeile stellen je ihre Geschwindigkeit dar.</p><p>Zeichne die Zusatzgeschwindigkeit ein. Du kannst Hilfspfeile einzeichnen, der zuletzt eingezeichnete Pfeil muss aber die Zusatzgeschwindigkeit darstellen.</p>",
        "shadows": [
            { type: 'image', src: 'szenario7.svg', x: 0, y: 0, width: 100, height: 60 }
        ],
        "style": '#layer1 > path {stroke:#888a85} #layer1 > path:last-child {stroke:#c00}',
        "check": createCheckerZusatzgeschwindigkeit(-20, 0)
    }
];

window.karokonstruktionTask = {
    levels: LEVELS
};
})(window);
